@@ -65,7 +65,7 @@ class CosmologyBase:
 
     def luminosity_distance(self, z):
         """luminosity distance for redshift in Mpc"""
-        pass
+        return np.vectorize(self._luminosity_distance)(z)
 
     def differential_comoving_volume(self, z):
         """differential comoving volume at redshift in Mpc**3"""
@@ -88,9 +88,8 @@ class CosmologyLAL(CosmologyBase):
         for k, v in lalomega.__dict__.items():
             setattr(self._lalomega, k, v)
 
-    @wraps(CosmologyBase.luminosity_distance)
-    def luminosity_distance(self, z):
-        return lal.LuminosityDistance(self._lalomega, z)
+    def _luminosity_distance(self, z):
+        return lal.LuminosityDistance(self._lalomega, float(z))
 
     @wraps(CosmologyBase.differential_comoving_volume)
     def differential_comoving_volume(self, z):
@@ -108,8 +107,7 @@ class CosmologyAstropy(CosmologyBase):
         super().__init__(**omega)
         self.cosmo = cosmology.FlatLambdaCDM(self.h, self.om)
 
-    @wraps(CosmologyBase.luminosity_distance)
-    def luminosity_distance(self, z):
+    def _luminosity_distance(self, z):
         return float(self.cosmo.luminosity_distance(z).to(units.Mpc).value)
 
     @wraps(CosmologyBase.differential_comoving_volume)
@@ -138,7 +136,7 @@ except ImportError:
     except ImportError:
         if _use('astropy'):
             raise ImportError("Could not import either LAL or astropy.")
-    logger.warning("Using astropy for cosmological calculations, which is slower that LAL.")
+    logger.warning("Using 'astropy' for cosmological calculations.  Install the 'lal' package for better performance.")
 
 ####################
 
